eyg/interpreter/simple_debug

A naive representation of EYG values as a string. Note the returned string can be any size and applications are best of writing their own visualisation.

Values

pub fn describe(reason: break.Reason(a, b)) -> String

Describe a reason to stop execution

pub fn inspect(value: value.Value(a, b)) -> String

Inspect a value.

Search Document